didkit_did_auth

Function didkit_did_auth 

#[unsafe(no_mangle)]
pub extern "C" fn didkit_did_auth( holder: *const c_char, proof_options_json: *const c_char, key_json: *const c_char, ) -> *const c_char
Issue a Verifiable Presentation for DIDAuth. Input parameters are the holder URI as a C string, and JSON C strings for the linked data proof options and the JWK for signing. On success, a newly-issued verifiable presentation is returned as a newly-allocated C string. The returned string should be freed using didkit_free_string. On failure, NULL is returned, and the error message can be retrieved using didkit_error_message.