didkit_did_url_dereference

Function didkit_did_url_dereference 

#[unsafe(no_mangle)]
pub extern "C" fn didkit_did_url_dereference( did_url: *const c_char, input_metadata_json: *const c_char, ) -> *const c_char
Resolve a DID to a DID Document. Arguments are a C string containing the DID URL to dereference, and a C string containing a JSON object for dereferencing input metadata. The return value on success is a newly-allocated C string containing either a resolved resource or a DID resolution result JSON object. On error, NULL is returned, and the error can be retrieved using didkit_error_message.