Module error

Module error 

Enums

Error

Constants

LAST_ERROR

Functions

didkit_error_code
Retrieve a numeric code for the most recent error encountered by a DIDKit C function. If there has not been an error, 0 is returned.
didkit_error_message
Retrieve a human-readable description of the most recent error encountered by a DIDKit C function. The returned string is valid until the next call to a DIDKit function in the current thread, and should not be mutated or freed. If there has not been any error, NULL is returned.