Enums
Constants
Functions
- didkit_
error_ code - Retrieve a numeric code for the most recent error encountered by a DIDKit C function. If there has not been an error, 0 is returned.
- didkit_
error_ message - Retrieve a human-readable description of the most recent error encountered by a DIDKit C
function. The returned string is valid until the next call to a DIDKit function in the current
thread, and should not be mutated or freed. If there has not been any error,
NULLis returned.